@@ -3,7 +3,6 @@
 # Any copyright is dedicated to the Public Domain.
 # http://creativecommons.org/publicdomain/zero/1.0/
 
-from collections import OrderedDict
 import os
 from pathlib import Path
 import subprocess
@@ -12,6 +11,7 @@ from glean_parser import kotlin
 from glean_parser import metrics
 from glean_parser import pings
 from glean_parser import translate
+from glean_parser.util import DictWrapper
 
 
 ROOT = Path(__file__).parent
@@ -88,6 +88,27 @@ def test_parser(tmpdir):
         content = fd.read()
         assert 'category = ""' in content
 
+    with (tmpdir / "GleanBuildInfo.kt").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        assert "buildDate = Calendar.getInstance" in content
+
+    run_linters(tmpdir.glob("*.kt"))
+
+
+def test_parser_all_metrics(tmpdir):
+    """Test translating ALL metric types to Kotlin files."""
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "all_metrics.yaml",
+        "kotlin",
+        tmpdir,
+        {"namespace": "Foo", "with_buildinfo": "false"},
+        {"allow_reserved": False},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(["AllMetrics.kt"])
+
     run_linters(tmpdir.glob("*.kt"))
 
 
@@ -123,10 +144,10 @@ def test_kotlin_generator():
     assert kdf("\n") == r'"\n"'
     assert kdf([42, "\n"]) == r'listOf(42, "\n")'
     assert (
-        kdf(OrderedDict([("key", "value"), ("key2", "value2")]))
+        kdf(DictWrapper([("key", "value"), ("key2", "value2")]))
         == r'mapOf("key" to "value", "key2" to "value2")'
     )
-    assert kdf(metrics.Lifetime.ping) == "Lifetime.Ping"
+    assert kdf(metrics.Lifetime.ping) == "Lifetime.PING"
 
 
 def test_metric_type_name():
@@ -356,7 +377,9 @@ def test_event_extra_keys_in_correct_order(tmpdir):
     with (tmpdir / "Event.kt").open("r", encoding="utf-8") as fd:
         content = fd.read()
         content = " ".join(content.split())
-        assert "exampleKeys { alice, bob, charlie }" in content
+        assert "EventExtraKey { alice {" in content
+        assert "bob {" in content
+        assert "charlie {" in content
         assert 'allowedExtraKeys = listOf("alice", "bob", "charlie")' in content
 
 
@@ -383,7 +406,7 @@ def test_arguments_are_generated_in_deterministic_order(tmpdir):
     with (tmpdir / "Event.kt").open("r", encoding="utf-8") as fd:
         content = fd.read()
         content = " ".join(content.split())
-        expected = 'EventMetricType<exampleKeys, NoExtras> by lazy { // generated from event.example EventMetricType<exampleKeys, NoExtras>( category = "event", name = "example", sendInPings = listOf("events"), lifetime = Lifetime.Ping, disabled = false, allowedExtraKeys = listOf("alice", "bob", "charlie") ) } }'  # noqa
+        expected = 'EventMetricType<exampleKeys, NoExtras> by lazy { // generated from event.example EventMetricType<exampleKeys, NoExtras>( CommonMetricData( category = "event", name = "example", sendInPings = listOf("events"), lifetime = Lifetime.PING, disabled = false ), allowedExtraKeys = listOf("alice", "bob", "charlie")) } }'  # noqa
         assert expected in content
 
 
